[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/keras-vision)](https://www.python.org/)  [![PyPI version](https://badge.fury.io/py/keras-vision.svg)](https://badge.fury.io/py/keras-vision) [![Keras](https://img.shields.io/badge/Keras%203.x-%23D00000.svg?logo=Keras&logoColor=white)](https://github.com/keras-team/keras/releases)

Porting all models from everywhere to Keras to leverage multi-backend support.

Cause why not?🤷🏻‍♂️

**Installation:**

1. Option 1: Install from PyPI: `pip install -U keras-vision`

2. Option 2: Install the latest updates present in the repository: `pip install git+https://github.com/veb-101/keras-vision.git`

**Usage:** Please refer to the `examples` folder

### Updates

1. [2024-05-04] Converted MobileViT to Keras 3 and released weights of all 3 variants.
   1. Jax backend currently not working, I'm working on a fix.
   2. Release: <https://github.com/veb-101/keras-vision/releases/tag/v0.4>
